@@ -23,6 +23,7 @@ from clu import AMQPActor
 from clu.client import AMQPReply
 
 from cluplus.configloader import Loader
+from cluplus.proxy import flatten
 
 from basecam import BaseCamera
 from basecam.actor import BaseCameraActor
@@ -34,6 +35,18 @@ from lvmcam.actor.commands import camera_parser
 #from lvmcam.model import fits_model, lvmcam_fz_fits_model
 from lvmcam.models import CameraCards, WcsCards, ScraperParamCards, ScraperDataStore, GenicamCards
 
+from lvmtipo.site import Site
+from lvmtipo.siderostat import Siderostat
+from lvmtipo.fiber import Fiber
+from lvmtipo.target import Target
+from lvmtipo.ambient import Ambient
+from lvmtipo.kmirror import Kmirror
+
+from astropy.utils import iers
+iers.conf.auto_download = False
+
+
+
 from araviscam import BlackflyCameraSystem, BlackflyCamera
 from skymakercam import SkymakerCameraSystem, SkymakerCamera
 
@@ -45,7 +58,6 @@ camera_types = {"araviscam": lambda *args, **kwargs: BlackflyCameraSystem(Blackf
 __all__ = ["LvmcamActor"]
 
 
-
 class LvmcamActor(BaseCameraActor, AMQPActor):
     """Lvmcam base actor."""
 
@@ -98,8 +110,30 @@ class LvmcamActor(BaseCameraActor, AMQPActor):
         self.basename = config.get("basename", None)
 
         self.exposure_state = {}
+#        self.log.debug(f"{config.get('scraper', [])}")
+        self.scraper_store = ScraperDataStore(self, config.get("scraper", {}))
+
+        self.site = Site(name = config.get("site", "LCO"))
+        self.log.info(f"Site: {config.get('site', 'LCO')}")
+
+        # but south-> north at LCO
+        if self.site.lat > 40.0:
+            azang = 180 # MPIA
+        else:
+            azang = 0  # LCO, APO, KHU
+        
+        medSign = -1
+
+        self.sid = Siderostat(azang=azang, medSign=medSign)
+        self.ambi = Ambient()
+
+        homeOffset = 135
+        homeIsWest = False
+
+        self.log.info(f"Site: {config.get('site', 'LCO')}, homeOffset: {homeOffset}, homeIsWest: {homeIsWest}, azang: {azang}, medSign {medSign}")
+
+        self.kmirror = Kmirror(home_is_west=homeIsWest, home_offset=homeOffset)
 
-        self.scraper_store = ScraperDataStore(config.get("scraper", {}))
 
     async def start(self):
         """Start actor and add cameras."""
@@ -114,7 +148,7 @@ class LvmcamActor(BaseCameraActor, AMQPActor):
 
         for camera in self.camera_system._config:
             try:
-                cam = await self.camera_system.add_camera(name=camera, actor=self, scraper_store=self.scraper_store)
+                cam = await self.camera_system.add_camera(name=camera, actor=self)
                 self.log.debug(f"camname {camera}")
                 self.log.debug(f"basename {self.basename}")
                 self.log.debug(f"dirname {self.dirname}")
@@ -156,8 +190,10 @@ class LvmcamActor(BaseCameraActor, AMQPActor):
         reply = AMQPReply(message, log=self.log)
         if reply.sender in self.scraper_store.actors() and reply.headers.get("message_code", None) in ":i":
             timestamp = apika.message.decode_timestamp(message.timestamp) if message.timestamp else datetime.utcnow()
+#            self.log.debug(f"{flatten(reply.body)}")
             self.scraper_store.update_with_actor_key_maps(reply.sender, reply.body, timestamp)
-#        self.log.debug(self.scraper_store.data)
+
+#        self.log.debug(f"{self.scraper_store.data}")
 
         return reply
 
